# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.agent.v1 import agent_list_params, agent_create_params, agent_update_params
from ....types.agent.v1.agent_list_response import AgentListResponse
from ....types.agent.v1.agent_create_response import AgentCreateResponse
from ....types.agent.v1.agent_delete_response import AgentDeleteResponse
from ....types.agent.v1.agent_update_response import AgentUpdateResponse
from ....types.agent.v1.agent_retrieve_response import AgentRetrieveResponse

__all__ = ["AgentsResource", "AsyncAgentsResource"]


class AgentsResource(SyncAPIResource):
    """
    Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
    """

    @cached_property
    def with_raw_response(self) -> AgentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AgentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AgentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AgentsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        instructions: str,
        name: str,
        description: str | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        model: str | Omit = omit,
        sandbox: Optional[agent_create_params.Sandbox] | Omit = omit,
        vault_groups: Optional[SequenceNotStr[str]] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentCreateResponse:
        """Creates a new agent definition with a scoped API key.

        The agent can then be used
        to create and execute runs.

        Args:
          instructions: System instructions that define agent behavior

          name: Display name for the agent

          description: Optional description of the agent

          disabled_tools: Denylist of tools the agent cannot use. Mutually exclusive with enabledTools —
              set one or the other, not both.

          enabled_tools: Allowlist of tools the agent can use. Mutually exclusive with disabledTools —
              set one or the other, not both.

          model: LLM model identifier (e.g. anthropic/claude-sonnet-4.6). Defaults to
              anthropic/claude-sonnet-4.6

          sandbox: Custom sandbox configuration (cpu, memoryMiB)

          vault_groups: Restrict agent to vaults within specific vault group IDs

          vault_ids: Restrict agent to specific vault IDs

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/agent/v1/agents",
            body=maybe_transform(
                {
                    "instructions": instructions,
                    "name": name,
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "model": model,
                    "sandbox": sandbox,
                    "vault_groups": vault_groups,
                    "vault_ids": vault_ids,
                },
                agent_create_params.AgentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentRetrieveResponse:
        """
        Retrieves a single agent definition by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            path_template("/agent/v1/agents/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        description: Optional[str] | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        instructions: str | Omit = omit,
        model: str | Omit = omit,
        name: str | Omit = omit,
        sandbox: Optional[object] | Omit = omit,
        vault_groups: Optional[SequenceNotStr[str]] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentUpdateResponse:
        """Updates an agent definition.

        Only provided fields are changed.

        Args:
          description: Updated agent description. Pass null to clear if supported by the client.

          disabled_tools: Denylist of tools the agent cannot use. Mutually exclusive with enabledTools —
              set one or the other, not both. Pass null to clear.

          enabled_tools: Allowlist of tools the agent can use. Mutually exclusive with disabledTools —
              set one or the other, not both. Pass null to clear.

          instructions: Updated system instructions that guide agent behavior

          model: Model identifier the agent should use for future runs

          name: Updated agent display name

          sandbox: Sandbox configuration override for future agent runs. Pass null to clear.

          vault_groups: Vault group IDs the agent can access. Pass null to clear.

          vault_ids: Vault IDs the agent can access directly. Pass null to clear.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            path_template("/agent/v1/agents/{id}", id=id),
            body=maybe_transform(
                {
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "instructions": instructions,
                    "model": model,
                    "name": name,
                    "sandbox": sandbox,
                    "vault_groups": vault_groups,
                    "vault_ids": vault_ids,
                },
                agent_update_params.AgentUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentUpdateResponse,
        )

    def list(
        self,
        *,
        cursor: str | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentListResponse:
        """
        Lists all active agents for the authenticated organization.

        Args:
          cursor: Pagination cursor (agent ID from previous page). Returns agents created before
              this agent.

          limit: Maximum number of agents to return (default 50, max 250)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/agent/v1/agents",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "cursor": cursor,
                        "limit": limit,
                    },
                    agent_list_params.AgentListParams,
                ),
            ),
            cast_to=AgentListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentDeleteResponse:
        """
        Soft-deletes an agent and revokes its scoped API key.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            path_template("/agent/v1/agents/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentDeleteResponse,
        )


class AsyncAgentsResource(AsyncAPIResource):
    """
    Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
    """

    @cached_property
    def with_raw_response(self) -> AsyncAgentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAgentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAgentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncAgentsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        instructions: str,
        name: str,
        description: str | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        model: str | Omit = omit,
        sandbox: Optional[agent_create_params.Sandbox] | Omit = omit,
        vault_groups: Optional[SequenceNotStr[str]] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentCreateResponse:
        """Creates a new agent definition with a scoped API key.

        The agent can then be used
        to create and execute runs.

        Args:
          instructions: System instructions that define agent behavior

          name: Display name for the agent

          description: Optional description of the agent

          disabled_tools: Denylist of tools the agent cannot use. Mutually exclusive with enabledTools —
              set one or the other, not both.

          enabled_tools: Allowlist of tools the agent can use. Mutually exclusive with disabledTools —
              set one or the other, not both.

          model: LLM model identifier (e.g. anthropic/claude-sonnet-4.6). Defaults to
              anthropic/claude-sonnet-4.6

          sandbox: Custom sandbox configuration (cpu, memoryMiB)

          vault_groups: Restrict agent to vaults within specific vault group IDs

          vault_ids: Restrict agent to specific vault IDs

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/agent/v1/agents",
            body=await async_maybe_transform(
                {
                    "instructions": instructions,
                    "name": name,
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "model": model,
                    "sandbox": sandbox,
                    "vault_groups": vault_groups,
                    "vault_ids": vault_ids,
                },
                agent_create_params.AgentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentRetrieveResponse:
        """
        Retrieves a single agent definition by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            path_template("/agent/v1/agents/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        description: Optional[str] | Omit = omit,
        disabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        enabled_tools: Optional[SequenceNotStr[str]] | Omit = omit,
        instructions: str | Omit = omit,
        model: str | Omit = omit,
        name: str | Omit = omit,
        sandbox: Optional[object] | Omit = omit,
        vault_groups: Optional[SequenceNotStr[str]] | Omit = omit,
        vault_ids: Optional[SequenceNotStr[str]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentUpdateResponse:
        """Updates an agent definition.

        Only provided fields are changed.

        Args:
          description: Updated agent description. Pass null to clear if supported by the client.

          disabled_tools: Denylist of tools the agent cannot use. Mutually exclusive with enabledTools —
              set one or the other, not both. Pass null to clear.

          enabled_tools: Allowlist of tools the agent can use. Mutually exclusive with disabledTools —
              set one or the other, not both. Pass null to clear.

          instructions: Updated system instructions that guide agent behavior

          model: Model identifier the agent should use for future runs

          name: Updated agent display name

          sandbox: Sandbox configuration override for future agent runs. Pass null to clear.

          vault_groups: Vault group IDs the agent can access. Pass null to clear.

          vault_ids: Vault IDs the agent can access directly. Pass null to clear.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            path_template("/agent/v1/agents/{id}", id=id),
            body=await async_maybe_transform(
                {
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "instructions": instructions,
                    "model": model,
                    "name": name,
                    "sandbox": sandbox,
                    "vault_groups": vault_groups,
                    "vault_ids": vault_ids,
                },
                agent_update_params.AgentUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentUpdateResponse,
        )

    async def list(
        self,
        *,
        cursor: str | Omit = omit,
        limit: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentListResponse:
        """
        Lists all active agents for the authenticated organization.

        Args:
          cursor: Pagination cursor (agent ID from previous page). Returns agents created before
              this agent.

          limit: Maximum number of agents to return (default 50, max 250)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/agent/v1/agents",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "cursor": cursor,
                        "limit": limit,
                    },
                    agent_list_params.AgentListParams,
                ),
            ),
            cast_to=AgentListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AgentDeleteResponse:
        """
        Soft-deletes an agent and revokes its scoped API key.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            path_template("/agent/v1/agents/{id}", id=id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AgentDeleteResponse,
        )


class AgentsResourceWithRawResponse:
    def __init__(self, agents: AgentsResource) -> None:
        self._agents = agents

        self.create = to_raw_response_wrapper(
            agents.create,
        )
        self.retrieve = to_raw_response_wrapper(
            agents.retrieve,
        )
        self.update = to_raw_response_wrapper(
            agents.update,
        )
        self.list = to_raw_response_wrapper(
            agents.list,
        )
        self.delete = to_raw_response_wrapper(
            agents.delete,
        )


class AsyncAgentsResourceWithRawResponse:
    def __init__(self, agents: AsyncAgentsResource) -> None:
        self._agents = agents

        self.create = async_to_raw_response_wrapper(
            agents.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            agents.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            agents.update,
        )
        self.list = async_to_raw_response_wrapper(
            agents.list,
        )
        self.delete = async_to_raw_response_wrapper(
            agents.delete,
        )


class AgentsResourceWithStreamingResponse:
    def __init__(self, agents: AgentsResource) -> None:
        self._agents = agents

        self.create = to_streamed_response_wrapper(
            agents.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            agents.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            agents.update,
        )
        self.list = to_streamed_response_wrapper(
            agents.list,
        )
        self.delete = to_streamed_response_wrapper(
            agents.delete,
        )


class AsyncAgentsResourceWithStreamingResponse:
    def __init__(self, agents: AsyncAgentsResource) -> None:
        self._agents = agents

        self.create = async_to_streamed_response_wrapper(
            agents.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            agents.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            agents.update,
        )
        self.list = async_to_streamed_response_wrapper(
            agents.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            agents.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SecretListResponse", "Group"]


class Group(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the secret group"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """When the secret group was created"""

    description: Optional[str] = None
    """Description of the secret group"""

    name: Optional[str] = None
    """Name of the secret group"""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """When the secret group was last updated"""


class SecretListResponse(BaseModel):
    groups: Optional[List[Group]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["V1ListVoicesParams"]


class V1ListVoicesParams(TypedDict, total=False):
    category: str
    """Filter by voice category"""

    collection_id: str
    """Filter by voice collection ID"""

    include_total_count: bool
    """Whether to include total count in response"""

    next_page_token: str
    """Token for retrieving the next page of results"""

    page_size: int
    """Number of voices to return per page (max 100)"""

    search: str
    """Search term to filter voices by name or description"""

    sort: Literal["name", "created_at", "updated_at"]
    """Field to sort by"""

    sort_direction: Literal["asc", "desc"]
    """Sort direction"""

    voice_type: Literal["premade", "cloned", "professional"]
    """Filter by voice type"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable, Optional
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.matters.v1 import party_list_params, party_create_params

__all__ = ["PartiesResource", "AsyncPartiesResource"]


class PartiesResource(SyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> PartiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return PartiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PartiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return PartiesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        addresses: Iterable[Dict[str, object]] | Omit = omit,
        custom_fields: Optional[Dict[str, object]] | Omit = omit,
        email: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        notes: Optional[str] | Omit = omit,
        phone: str | Omit = omit,
        type: Literal["person", "organization"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a reusable legal party for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/matters/v1/parties",
            body=maybe_transform(
                {
                    "name": name,
                    "addresses": addresses,
                    "custom_fields": custom_fields,
                    "email": email,
                    "metadata": metadata,
                    "notes": notes,
                    "phone": phone,
                    "type": type,
                },
                party_create_params.PartyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        party_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get a reusable legal party by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not party_id:
            raise ValueError(f"Expected a non-empty value for `party_id` but received {party_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            path_template("/matters/v1/parties/{party_id}", party_id=party_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update(
        self,
        party_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a reusable legal party.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not party_id:
            raise ValueError(f"Expected a non-empty value for `party_id` but received {party_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            path_template("/matters/v1/parties/{party_id}", party_id=party_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        email: str | Omit = omit,
        query: str | Omit = omit,
        type: Literal["person", "organization"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List reusable legal parties for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/matters/v1/parties",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "email": email,
                        "query": query,
                        "type": type,
                    },
                    party_list_params.PartyListParams,
                ),
            ),
            cast_to=NoneType,
        )


class AsyncPartiesResource(AsyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> AsyncPartiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPartiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPartiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncPartiesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        addresses: Iterable[Dict[str, object]] | Omit = omit,
        custom_fields: Optional[Dict[str, object]] | Omit = omit,
        email: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        notes: Optional[str] | Omit = omit,
        phone: str | Omit = omit,
        type: Literal["person", "organization"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a reusable legal party for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/matters/v1/parties",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "addresses": addresses,
                    "custom_fields": custom_fields,
                    "email": email,
                    "metadata": metadata,
                    "notes": notes,
                    "phone": phone,
                    "type": type,
                },
                party_create_params.PartyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        party_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get a reusable legal party by ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not party_id:
            raise ValueError(f"Expected a non-empty value for `party_id` but received {party_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            path_template("/matters/v1/parties/{party_id}", party_id=party_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update(
        self,
        party_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a reusable legal party.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not party_id:
            raise ValueError(f"Expected a non-empty value for `party_id` but received {party_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            path_template("/matters/v1/parties/{party_id}", party_id=party_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        email: str | Omit = omit,
        query: str | Omit = omit,
        type: Literal["person", "organization"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List reusable legal parties for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/matters/v1/parties",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "email": email,
                        "query": query,
                        "type": type,
                    },
                    party_list_params.PartyListParams,
                ),
            ),
            cast_to=NoneType,
        )


class PartiesResourceWithRawResponse:
    def __init__(self, parties: PartiesResource) -> None:
        self._parties = parties

        self.create = to_raw_response_wrapper(
            parties.create,
        )
        self.retrieve = to_raw_response_wrapper(
            parties.retrieve,
        )
        self.update = to_raw_response_wrapper(
            parties.update,
        )
        self.list = to_raw_response_wrapper(
            parties.list,
        )


class AsyncPartiesResourceWithRawResponse:
    def __init__(self, parties: AsyncPartiesResource) -> None:
        self._parties = parties

        self.create = async_to_raw_response_wrapper(
            parties.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            parties.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            parties.update,
        )
        self.list = async_to_raw_response_wrapper(
            parties.list,
        )


class PartiesResourceWithStreamingResponse:
    def __init__(self, parties: PartiesResource) -> None:
        self._parties = parties

        self.create = to_streamed_response_wrapper(
            parties.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            parties.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            parties.update,
        )
        self.list = to_streamed_response_wrapper(
            parties.list,
        )


class AsyncPartiesResourceWithStreamingResponse:
    def __init__(self, parties: AsyncPartiesResource) -> None:
        self._parties = parties

        self.create = async_to_streamed_response_wrapper(
            parties.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            parties.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            parties.update,
        )
        self.list = async_to_streamed_response_wrapper(
            parties.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1ResearchResponse"]


class V1ResearchResponse(BaseModel):
    model: Optional[str] = None
    """Model used for research"""

    research_id: Optional[str] = FieldInfo(alias="researchId", default=None)
    """Unique identifier for this research"""

    results: Optional[object] = None
    """Research findings and analysis"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["GroupCreateParams"]


class GroupCreateParams(TypedDict, total=False):
    name: Required[str]
    """Human-readable name for the vault group"""

    description: str
    """Optional description of the vault group purpose"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.skills import custom_list_params
from ...types.skills.custom_list_response import CustomListResponse

__all__ = ["CustomResource", "AsyncCustomResource"]


class CustomResource(SyncAPIResource):
    """Search and read legal AI skills for agents"""

    @cached_property
    def with_raw_response(self) -> CustomResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return CustomResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CustomResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return CustomResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        cursor: str | Omit = omit,
        limit: int | Omit = omit,
        tag: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomListResponse:
        """List all custom skills for the authenticated organization.

        Supports cursor-based
        pagination.

        Args:
          cursor: Cursor for pagination (skill ID from previous page)

          limit: Maximum number of results (1-100)

          tag: Filter by tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/skills/custom",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "cursor": cursor,
                        "limit": limit,
                        "tag": tag,
                    },
                    custom_list_params.CustomListParams,
                ),
            ),
            cast_to=CustomListResponse,
        )


class AsyncCustomResource(AsyncAPIResource):
    """Search and read legal AI skills for agents"""

    @cached_property
    def with_raw_response(self) -> AsyncCustomResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCustomResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCustomResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncCustomResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        cursor: str | Omit = omit,
        limit: int | Omit = omit,
        tag: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CustomListResponse:
        """List all custom skills for the authenticated organization.

        Supports cursor-based
        pagination.

        Args:
          cursor: Cursor for pagination (skill ID from previous page)

          limit: Maximum number of results (1-100)

          tag: Filter by tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/skills/custom",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "cursor": cursor,
                        "limit": limit,
                        "tag": tag,
                    },
                    custom_list_params.CustomListParams,
                ),
            ),
            cast_to=CustomListResponse,
        )


class CustomResourceWithRawResponse:
    def __init__(self, custom: CustomResource) -> None:
        self._custom = custom

        self.list = to_raw_response_wrapper(
            custom.list,
        )


class AsyncCustomResourceWithRawResponse:
    def __init__(self, custom: AsyncCustomResource) -> None:
        self._custom = custom

        self.list = async_to_raw_response_wrapper(
            custom.list,
        )


class CustomResourceWithStreamingResponse:
    def __init__(self, custom: CustomResource) -> None:
        self._custom = custom

        self.list = to_streamed_response_wrapper(
            custom.list,
        )


class AsyncCustomResourceWithStreamingResponse:
    def __init__(self, custom: AsyncCustomResource) -> None:
        self._custom = custom

        self.list = async_to_streamed_response_wrapper(
            custom.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, TypedDict

__all__ = ["BoostListGenerateParams"]


class BoostListGenerateParams(TypedDict, total=False):
    transcription_job_id: Required[str]
    """Completed pass-1 transcription job ID (tr\\__...)"""

    categories: List[Literal["person", "organization", "legal_term", "medical", "citation", "email"]]
    """Optional filter for entity categories to extract"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["BoostListExtractResponse", "Item"]


class Item(BaseModel):
    boost_param: Optional[Literal["low", "default", "high"]] = None

    category: Optional[str] = None

    word: Optional[str] = None


class BoostListExtractResponse(BaseModel):
    items: Optional[List[Item]] = None

    source: Optional[Literal["document", "text"]] = None

    source_ids: Optional[List[str]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_list_params import V1ListParams as V1ListParams
from .v1_create_params import V1CreateParams as V1CreateParams
from .v1_list_response import V1ListResponse as V1ListResponse
from .v1_search_params import V1SearchParams as V1SearchParams
from .v1_create_response import V1CreateResponse as V1CreateResponse
from .v1_delete_response import V1DeleteResponse as V1DeleteResponse
from .v1_search_response import V1SearchResponse as V1SearchResponse
from .v1_delete_all_params import V1DeleteAllParams as V1DeleteAllParams
from .v1_retrieve_response import V1RetrieveResponse as V1RetrieveResponse
from .v1_delete_all_response import V1DeleteAllResponse as V1DeleteAllResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ProjectCreateResponse", "DefaultBranch"]


class DefaultBranch(BaseModel):
    """Default 'main' branch details"""

    id: Optional[str] = None
    """Branch ID"""

    name: Optional[str] = None
    """Branch name"""


class ProjectCreateResponse(BaseModel):
    id: str
    """Project ID"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """Project creation timestamp"""

    default_branch: DefaultBranch = FieldInfo(alias="defaultBranch")
    """Default 'main' branch details"""

    name: str
    """Project name"""

    pg_version: int = FieldInfo(alias="pgVersion")
    """PostgreSQL major version"""

    region: str
    """AWS region"""

    status: Literal["active", "suspended", "deleted"]
    """Project status"""

    description: Optional[str] = None
    """Project description"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1FindParams"]


class V1FindParams(TypedDict, total=False):
    query: Required[str]
    """Search query (e.g., "fair use copyright", "Miranda rights")"""

    jurisdiction: str
    """
    Optional jurisdiction ID from resolveJurisdiction (e.g., "california",
    "us-federal")
    """

    num_results: Annotated[int, PropertyInfo(alias="numResults")]
    """Number of results 1-25 (default: 10)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.matters.v1 import agent_type_list_params, agent_type_create_params

__all__ = ["AgentTypesResource", "AsyncAgentTypesResource"]


class AgentTypesResource(SyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> AgentTypesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AgentTypesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AgentTypesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AgentTypesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        instructions: str,
        name: str,
        description: str | Omit = omit,
        disabled_tools: SequenceNotStr[str] | Omit = omit,
        enabled_tools: SequenceNotStr[str] | Omit = omit,
        is_active: bool | Omit = omit,
        is_default: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        model: str | Omit = omit,
        skill_refs: SequenceNotStr[str] | Omit = omit,
        slug: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a reusable agent role for legal matter orchestration.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/matters/v1/agent-types",
            body=maybe_transform(
                {
                    "instructions": instructions,
                    "name": name,
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "is_active": is_active,
                    "is_default": is_default,
                    "metadata": metadata,
                    "model": model,
                    "skill_refs": skill_refs,
                    "slug": slug,
                },
                agent_type_create_params.AgentTypeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        active: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List reusable agent roles for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/matters/v1/agent-types",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"active": active}, agent_type_list_params.AgentTypeListParams),
            ),
            cast_to=NoneType,
        )


class AsyncAgentTypesResource(AsyncAPIResource):
    """Matter-native legal workspaces and orchestration primitives"""

    @cached_property
    def with_raw_response(self) -> AsyncAgentTypesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAgentTypesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAgentTypesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncAgentTypesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        instructions: str,
        name: str,
        description: str | Omit = omit,
        disabled_tools: SequenceNotStr[str] | Omit = omit,
        enabled_tools: SequenceNotStr[str] | Omit = omit,
        is_active: bool | Omit = omit,
        is_default: bool | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        model: str | Omit = omit,
        skill_refs: SequenceNotStr[str] | Omit = omit,
        slug: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create a reusable agent role for legal matter orchestration.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/matters/v1/agent-types",
            body=await async_maybe_transform(
                {
                    "instructions": instructions,
                    "name": name,
                    "description": description,
                    "disabled_tools": disabled_tools,
                    "enabled_tools": enabled_tools,
                    "is_active": is_active,
                    "is_default": is_default,
                    "metadata": metadata,
                    "model": model,
                    "skill_refs": skill_refs,
                    "slug": slug,
                },
                agent_type_create_params.AgentTypeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        active: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        List reusable agent roles for the authenticated organization.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/matters/v1/agent-types",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"active": active}, agent_type_list_params.AgentTypeListParams),
            ),
            cast_to=NoneType,
        )


class AgentTypesResourceWithRawResponse:
    def __init__(self, agent_types: AgentTypesResource) -> None:
        self._agent_types = agent_types

        self.create = to_raw_response_wrapper(
            agent_types.create,
        )
        self.list = to_raw_response_wrapper(
            agent_types.list,
        )


class AsyncAgentTypesResourceWithRawResponse:
    def __init__(self, agent_types: AsyncAgentTypesResource) -> None:
        self._agent_types = agent_types

        self.create = async_to_raw_response_wrapper(
            agent_types.create,
        )
        self.list = async_to_raw_response_wrapper(
            agent_types.list,
        )


class AgentTypesResourceWithStreamingResponse:
    def __init__(self, agent_types: AgentTypesResource) -> None:
        self._agent_types = agent_types

        self.create = to_streamed_response_wrapper(
            agent_types.create,
        )
        self.list = to_streamed_response_wrapper(
            agent_types.list,
        )


class AsyncAgentTypesResourceWithStreamingResponse:
    def __init__(self, agent_types: AsyncAgentTypesResource) -> None:
        self._agent_types = agent_types

        self.create = async_to_streamed_response_wrapper(
            agent_types.create,
        )
        self.list = async_to_streamed_response_wrapper(
            agent_types.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["VaultUploadParams"]


class VaultUploadParams(TypedDict, total=False):
    content_type: Required[Annotated[str, PropertyInfo(alias="contentType")]]
    """MIME type of the file (e.g., application/pdf, image/jpeg)"""

    filename: Required[str]
    """Name of the file to upload"""

    auto_index: bool
    """Whether to automatically process and index the file for search"""

    metadata: object
    """Additional metadata to associate with the file"""

    path: str
    """Optional folder path for hierarchy preservation.

    Allows integrations to maintain source folder structure from systems like
    NetDocs, Clio, or Smokeball. Example: '/Discovery/Depositions/2024'
    """

    size_bytes: Annotated[int, PropertyInfo(alias="sizeBytes")]
    """File size in bytes (optional, max 5GB for single PUT uploads).

    When provided, enforces exact file size at S3 level.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .inboxes import (
    InboxesResource,
    AsyncInboxesResource,
    InboxesResourceWithRawResponse,
    AsyncInboxesResourceWithRawResponse,
    InboxesResourceWithStreamingResponse,
    AsyncInboxesResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def inboxes(self) -> InboxesResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return InboxesResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def inboxes(self) -> AsyncInboxesResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncInboxesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

    @cached_property
    def inboxes(self) -> InboxesResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return InboxesResourceWithRawResponse(self._v1.inboxes)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

    @cached_property
    def inboxes(self) -> AsyncInboxesResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncInboxesResourceWithRawResponse(self._v1.inboxes)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

    @cached_property
    def inboxes(self) -> InboxesResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return InboxesResourceWithStreamingResponse(self._v1.inboxes)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

    @cached_property
    def inboxes(self) -> AsyncInboxesResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncInboxesResourceWithStreamingResponse(self._v1.inboxes)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["SecretUpdateGroupResponse"]


class SecretUpdateGroupResponse(BaseModel):
    created: Optional[float] = None
    """Number of new secrets created"""

    group: Optional[str] = None
    """Name of the secret group"""

    message: Optional[str] = None

    success: Optional[bool] = None

    updated: Optional[float] = None
    """Number of existing secrets updated"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev._utils import parse_date
from casedev.types.legal import (
    V1FindResponse,
    V1DraftResponse,
    V1DocketResponse,
    V1VerifyResponse,
    V1SimilarResponse,
    V1ResearchResponse,
    V1SecFilingResponse,
    V1ListCourtsResponse,
    V1GetFullTextResponse,
    V1GetCitationsResponse,
    V1PatentSearchResponse,
    V1TrademarkSearchResponse,
    V1ListJurisdictionsResponse,
    V1GetCitationsFromURLResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_docket(self, client: Casedev) -> None:
        v1 = client.legal.v1.docket(
            type="search",
        )
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    def test_method_docket_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.docket(
            type="search",
            acknowledge_pacer_fees=True,
            court="court",
            date_filed_after=parse_date("2019-12-27"),
            date_filed_before=parse_date("2019-12-27"),
            docket_id="docketId",
            include_entries=True,
            limit=1,
            live=True,
            offset=0,
            query="xx",
        )
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_docket(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.docket(
            type="search",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_docket(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.docket(
            type="search",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1DocketResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_draft(self, client: Casedev) -> None:
        v1 = client.legal.v1.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        )
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    def test_method_draft_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
            citations=True,
            format="format",
            length={
                "target": 0,
                "unit": "words",
            },
            model="model",
            object_ids=["string"],
            output_name="output_name",
            output_type="pdf",
            verified=True,
        )
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_draft(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_draft(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1DraftResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_find(self, client: Casedev) -> None:
        v1 = client.legal.v1.find(
            query="xxx",
        )
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    def test_method_find_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.find(
            query="xxx",
            jurisdiction="jurisdiction",
            num_results=1,
        )
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_find(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.find(
            query="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_find(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.find(
            query="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1FindResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_citations(self, client: Casedev) -> None:
        v1 = client.legal.v1.get_citations(
            text="text",
        )
        assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_get_citations(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.get_citations(
            text="text",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_get_citations(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.get_citations(
            text="text",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_citations_from_url(self, client: Casedev) -> None:
        v1 = client.legal.v1.get_citations_from_url(
            url="https://example.com",
        )
        assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_get_citations_from_url(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.get_citations_from_url(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_get_citations_from_url(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.get_citations_from_url(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get_full_text(self, client: Casedev) -> None:
        v1 = client.legal.v1.get_full_text(
            url="https://example.com",
        )
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    def test_method_get_full_text_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.get_full_text(
            url="https://example.com",
            highlight_query="highlightQuery",
            max_characters=1000,
            summary_query="summaryQuery",
        )
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_get_full_text(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.get_full_text(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_get_full_text(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.get_full_text(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list_courts(self, client: Casedev) -> None:
        v1 = client.legal.v1.list_courts()
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    def test_method_list_courts_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.list_courts(
            in_use_only=True,
            jurisdiction="jurisdiction",
            limit=1,
            offset=0,
            query="xx",
        )
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_list_courts(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.list_courts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_list_courts(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.list_courts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list_jurisdictions(self, client: Casedev) -> None:
        v1 = client.legal.v1.list_jurisdictions(
            name="xx",
        )
        assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_list_jurisdictions(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.list_jurisdictions(
            name="xx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_list_jurisdictions(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.list_jurisdictions(
            name="xx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_patent_search(self, client: Casedev) -> None:
        v1 = client.legal.v1.patent_search(
            query="x",
        )
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    def test_method_patent_search_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.patent_search(
            query="x",
            application_status="applicationStatus",
            application_type="Utility",
            assignee="assignee",
            filing_date_from=parse_date("2019-12-27"),
            filing_date_to=parse_date("2019-12-27"),
            grant_date_from=parse_date("2019-12-27"),
            grant_date_to=parse_date("2019-12-27"),
            inventor="inventor",
            limit=1,
            offset=0,
            sort_by="filingDate",
            sort_order="asc",
        )
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_patent_search(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.patent_search(
            query="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_patent_search(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.patent_search(
            query="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_research(self, client: Casedev) -> None:
        v1 = client.legal.v1.research(
            query="xxx",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_method_research_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.research(
            query="xxx",
            additional_queries=["string"],
            jurisdiction="jurisdiction",
            num_results=1,
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_research(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.research(
            query="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_research(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.research(
            query="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_sec_filing(self, client: Casedev) -> None:
        v1 = client.legal.v1.sec_filing(
            type="search",
        )
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    def test_method_sec_filing_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.sec_filing(
            type="search",
            cik="cik",
            date_after=parse_date("2019-12-27"),
            date_before=parse_date("2019-12-27"),
            entity="entity",
            form_types=["string"],
            limit=1,
            offset=0,
            query="xx",
            ticker="ticker",
        )
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_sec_filing(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.sec_filing(
            type="search",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_sec_filing(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.sec_filing(
            type="search",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1SecFilingResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_similar(self, client: Casedev) -> None:
        v1 = client.legal.v1.similar(
            url="https://example.com",
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_method_similar_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.similar(
            url="https://example.com",
            jurisdiction="jurisdiction",
            num_results=1,
            start_published_date=parse_date("2019-12-27"),
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_similar(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.similar(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_similar(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.similar(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1SimilarResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_trademark_search(self, client: Casedev) -> None:
        v1 = client.legal.v1.trademark_search()
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    def test_method_trademark_search_with_all_params(self, client: Casedev) -> None:
        v1 = client.legal.v1.trademark_search(
            registration_number="registrationNumber",
            serial_number="serialNumber",
        )
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_trademark_search(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.trademark_search()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_trademark_search(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.trademark_search() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_verify(self, client: Casedev) -> None:
        v1 = client.legal.v1.verify(
            text="text",
        )
        assert_matches_type(V1VerifyResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_verify(self, client: Casedev) -> None:
        response = client.legal.v1.with_raw_response.verify(
            text="text",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1VerifyResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_verify(self, client: Casedev) -> None:
        with client.legal.v1.with_streaming_response.verify(
            text="text",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1VerifyResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_docket(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.docket(
            type="search",
        )
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    async def test_method_docket_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.docket(
            type="search",
            acknowledge_pacer_fees=True,
            court="court",
            date_filed_after=parse_date("2019-12-27"),
            date_filed_before=parse_date("2019-12-27"),
            docket_id="docketId",
            include_entries=True,
            limit=1,
            live=True,
            offset=0,
            query="xx",
        )
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_docket(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.docket(
            type="search",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1DocketResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_docket(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.docket(
            type="search",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1DocketResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_draft(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        )
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    async def test_method_draft_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
            citations=True,
            format="format",
            length={
                "target": 0,
                "unit": "words",
            },
            model="model",
            object_ids=["string"],
            output_name="output_name",
            output_type="pdf",
            verified=True,
        )
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_draft(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1DraftResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_draft(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.draft(
            instructions="xxxxxxxxxx",
            vault_id="vault_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1DraftResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_find(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.find(
            query="xxx",
        )
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    async def test_method_find_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.find(
            query="xxx",
            jurisdiction="jurisdiction",
            num_results=1,
        )
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_find(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.find(
            query="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1FindResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_find(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.find(
            query="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1FindResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_citations(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.get_citations(
            text="text",
        )
        assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_get_citations(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.get_citations(
            text="text",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_get_citations(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.get_citations(
            text="text",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetCitationsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_citations_from_url(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.get_citations_from_url(
            url="https://example.com",
        )
        assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_get_citations_from_url(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.get_citations_from_url(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_get_citations_from_url(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.get_citations_from_url(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetCitationsFromURLResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get_full_text(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.get_full_text(
            url="https://example.com",
        )
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    async def test_method_get_full_text_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.get_full_text(
            url="https://example.com",
            highlight_query="highlightQuery",
            max_characters=1000,
            summary_query="summaryQuery",
        )
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_get_full_text(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.get_full_text(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_get_full_text(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.get_full_text(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetFullTextResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list_courts(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.list_courts()
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    async def test_method_list_courts_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.list_courts(
            in_use_only=True,
            jurisdiction="jurisdiction",
            limit=1,
            offset=0,
            query="xx",
        )
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_list_courts(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.list_courts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_list_courts(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.list_courts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ListCourtsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list_jurisdictions(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.list_jurisdictions(
            name="xx",
        )
        assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_list_jurisdictions(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.list_jurisdictions(
            name="xx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_list_jurisdictions(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.list_jurisdictions(
            name="xx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ListJurisdictionsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_patent_search(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.patent_search(
            query="x",
        )
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_patent_search_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.patent_search(
            query="x",
            application_status="applicationStatus",
            application_type="Utility",
            assignee="assignee",
            filing_date_from=parse_date("2019-12-27"),
            filing_date_to=parse_date("2019-12-27"),
            grant_date_from=parse_date("2019-12-27"),
            grant_date_to=parse_date("2019-12-27"),
            inventor="inventor",
            limit=1,
            offset=0,
            sort_by="filingDate",
            sort_order="asc",
        )
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_patent_search(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.patent_search(
            query="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_patent_search(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.patent_search(
            query="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1PatentSearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_research(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.research(
            query="xxx",
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_research_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.research(
            query="xxx",
            additional_queries=["string"],
            jurisdiction="jurisdiction",
            num_results=1,
        )
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_research(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.research(
            query="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ResearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_research(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.research(
            query="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ResearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_sec_filing(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.sec_filing(
            type="search",
        )
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    async def test_method_sec_filing_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.sec_filing(
            type="search",
            cik="cik",
            date_after=parse_date("2019-12-27"),
            date_before=parse_date("2019-12-27"),
            entity="entity",
            form_types=["string"],
            limit=1,
            offset=0,
            query="xx",
            ticker="ticker",
        )
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_sec_filing(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.sec_filing(
            type="search",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1SecFilingResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_sec_filing(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.sec_filing(
            type="search",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1SecFilingResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_similar(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.similar(
            url="https://example.com",
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_method_similar_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.similar(
            url="https://example.com",
            jurisdiction="jurisdiction",
            num_results=1,
            start_published_date=parse_date("2019-12-27"),
        )
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_similar(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.similar(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1SimilarResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_similar(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.similar(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1SimilarResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_trademark_search(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.trademark_search()
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    async def test_method_trademark_search_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.trademark_search(
            registration_number="registrationNumber",
            serial_number="serialNumber",
        )
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_trademark_search(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.trademark_search()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_trademark_search(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.trademark_search() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1TrademarkSearchResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_verify(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.legal.v1.verify(
            text="text",
        )
        assert_matches_type(V1VerifyResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_verify(self, async_client: AsyncCasedev) -> None:
        response = await async_client.legal.v1.with_raw_response.verify(
            text="text",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1VerifyResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_verify(self, async_client: AsyncCasedev) -> None:
        async with async_client.legal.v1.with_streaming_response.verify(
            text="text",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1VerifyResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["V1DetectParams"]


class V1DetectParams(TypedDict, total=False):
    q: Required[Union[str, SequenceNotStr[str]]]
    """Text to detect language for.

    Can be a single string or an array for batch detection.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["ChatReplyToQuestionParams"]


class ChatReplyToQuestionParams(TypedDict, total=False):
    id: Required[str]

    answers: Required[Iterable[SequenceNotStr[str]]]
    """Answer selections for each prompt element in the pending question"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = ["RunCreateParams"]


class RunCreateParams(TypedDict, total=False):
    agent_id: Required[Annotated[str, PropertyInfo(alias="agentId")]]
    """ID of the agent to run"""

    prompt: Required[str]
    """Task prompt for the agent"""

    callback_url: Annotated[Optional[str], PropertyInfo(alias="callbackUrl")]
    """HTTPS callback URL to receive a notification when the run completes.

    Registered atomically with the run — eliminates the race condition of calling
    /watch after /exec. Additional watchers can still be added via POST
    /run/:id/watch.
    """

    guidance: Optional[str]
    """Additional guidance for this run"""

    model: Optional[str]
    """Override the agent default model for this run"""

    object_ids: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="objectIds")]
    """Scope this run to specific vault object IDs.

    The agent will only be able to access these objects during execution.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.vault import (
    MemoryListResponse,
    MemoryCreateResponse,
    MemorySearchResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMemory:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        memory = client.vault.memory.create(
            id="id",
            content="content",
            type="fact",
        )
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        memory = client.vault.memory.create(
            id="id",
            content="content",
            type="fact",
            source="source",
            tags=["string"],
        )
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.vault.memory.with_raw_response.create(
            id="id",
            content="content",
            type="fact",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = response.parse()
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.vault.memory.with_streaming_response.create(
            id="id",
            content="content",
            type="fact",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = response.parse()
            assert_matches_type(MemoryCreateResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.memory.with_raw_response.create(
                id="",
                content="content",
                type="fact",
            )

    @parametrize
    def test_method_update(self, client: Casedev) -> None:
        memory = client.vault.memory.update(
            entry_id="entryId",
            id="id",
        )
        assert memory is None

    @parametrize
    def test_method_update_with_all_params(self, client: Casedev) -> None:
        memory = client.vault.memory.update(
            entry_id="entryId",
            id="id",
            content="content",
            source="source",
            tags=["string"],
        )
        assert memory is None

    @parametrize
    def test_raw_response_update(self, client: Casedev) -> None:
        response = client.vault.memory.with_raw_response.update(
            entry_id="entryId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = response.parse()
        assert memory is None

    @parametrize
    def test_streaming_response_update(self, client: Casedev) -> None:
        with client.vault.memory.with_streaming_response.update(
            entry_id="entryId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = response.parse()
            assert memory is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.memory.with_raw_response.update(
                entry_id="entryId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `entry_id` but received ''"):
            client.vault.memory.with_raw_response.update(
                entry_id="",
                id="id",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        memory = client.vault.memory.list(
            "id",
        )
        assert_matches_type(MemoryListResponse, memory, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.vault.memory.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = response.parse()
        assert_matches_type(MemoryListResponse, memory, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.vault.memory.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = response.parse()
            assert_matches_type(MemoryListResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.memory.with_raw_response.list(
                "",
            )

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        memory = client.vault.memory.delete(
            entry_id="entryId",
            id="id",
        )
        assert memory is None

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.vault.memory.with_raw_response.delete(
            entry_id="entryId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = response.parse()
        assert memory is None

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.vault.memory.with_streaming_response.delete(
            entry_id="entryId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = response.parse()
            assert memory is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.memory.with_raw_response.delete(
                entry_id="entryId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `entry_id` but received ''"):
            client.vault.memory.with_raw_response.delete(
                entry_id="",
                id="id",
            )

    @parametrize
    def test_method_search(self, client: Casedev) -> None:
        memory = client.vault.memory.search(
            id="id",
            query="query",
        )
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    def test_method_search_with_all_params(self, client: Casedev) -> None:
        memory = client.vault.memory.search(
            id="id",
            query="query",
            limit=1,
            tags=["string"],
            types=["string"],
        )
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    def test_raw_response_search(self, client: Casedev) -> None:
        response = client.vault.memory.with_raw_response.search(
            id="id",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = response.parse()
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    def test_streaming_response_search(self, client: Casedev) -> None:
        with client.vault.memory.with_streaming_response.search(
            id="id",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = response.parse()
            assert_matches_type(MemorySearchResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_search(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.memory.with_raw_response.search(
                id="",
                query="query",
            )


class TestAsyncMemory:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.create(
            id="id",
            content="content",
            type="fact",
        )
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.create(
            id="id",
            content="content",
            type="fact",
            source="source",
            tags=["string"],
        )
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.memory.with_raw_response.create(
            id="id",
            content="content",
            type="fact",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = await response.parse()
        assert_matches_type(MemoryCreateResponse, memory, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.memory.with_streaming_response.create(
            id="id",
            content="content",
            type="fact",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = await response.parse()
            assert_matches_type(MemoryCreateResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.memory.with_raw_response.create(
                id="",
                content="content",
                type="fact",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.update(
            entry_id="entryId",
            id="id",
        )
        assert memory is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.update(
            entry_id="entryId",
            id="id",
            content="content",
            source="source",
            tags=["string"],
        )
        assert memory is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.memory.with_raw_response.update(
            entry_id="entryId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = await response.parse()
        assert memory is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.memory.with_streaming_response.update(
            entry_id="entryId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = await response.parse()
            assert memory is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.memory.with_raw_response.update(
                entry_id="entryId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `entry_id` but received ''"):
            await async_client.vault.memory.with_raw_response.update(
                entry_id="",
                id="id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.list(
            "id",
        )
        assert_matches_type(MemoryListResponse, memory, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.memory.with_raw_response.list(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = await response.parse()
        assert_matches_type(MemoryListResponse, memory, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.memory.with_streaming_response.list(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = await response.parse()
            assert_matches_type(MemoryListResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.memory.with_raw_response.list(
                "",
            )

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.delete(
            entry_id="entryId",
            id="id",
        )
        assert memory is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.memory.with_raw_response.delete(
            entry_id="entryId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = await response.parse()
        assert memory is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.memory.with_streaming_response.delete(
            entry_id="entryId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = await response.parse()
            assert memory is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.memory.with_raw_response.delete(
                entry_id="entryId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `entry_id` but received ''"):
            await async_client.vault.memory.with_raw_response.delete(
                entry_id="",
                id="id",
            )

    @parametrize
    async def test_method_search(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.search(
            id="id",
            query="query",
        )
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncCasedev) -> None:
        memory = await async_client.vault.memory.search(
            id="id",
            query="query",
            limit=1,
            tags=["string"],
            types=["string"],
        )
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    async def test_raw_response_search(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.memory.with_raw_response.search(
            id="id",
            query="query",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        memory = await response.parse()
        assert_matches_type(MemorySearchResponse, memory, path=["response"])

    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.memory.with_streaming_response.search(
            id="id",
            query="query",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            memory = await response.parse()
            assert_matches_type(MemorySearchResponse, memory, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_search(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.memory.with_raw_response.search(
                id="",
                query="query",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SecretRetrieveGroupParams"]


class SecretRetrieveGroupParams(TypedDict, total=False):
    env: str
    """Environment name. If not specified, uses the default environment"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["PartyCreateParams"]


class PartyCreateParams(TypedDict, total=False):
    name: Required[str]

    addresses: Iterable[Dict[str, object]]

    custom_fields: Optional[Dict[str, object]]

    email: str

    metadata: Dict[str, object]

    notes: Optional[str]

    phone: str

    type: Literal["person", "organization"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .run import (
    RunResource,
    AsyncRunResource,
    RunResourceWithRawResponse,
    AsyncRunResourceWithRawResponse,
    RunResourceWithStreamingResponse,
    AsyncRunResourceWithStreamingResponse,
)
from .execute import (
    ExecuteResource,
    AsyncExecuteResource,
    ExecuteResourceWithRawResponse,
    AsyncExecuteResourceWithRawResponse,
    ExecuteResourceWithStreamingResponse,
    AsyncExecuteResourceWithStreamingResponse,
)
from .chat.chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def run(self) -> RunResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return RunResource(self._client)

    @cached_property
    def execute(self) -> ExecuteResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ExecuteResource(self._client)

    @cached_property
    def chat(self) -> ChatResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ChatResource(self._client)

    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def run(self) -> AsyncRunResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncRunResource(self._client)

    @cached_property
    def execute(self) -> AsyncExecuteResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncExecuteResource(self._client)

    @cached_property
    def chat(self) -> AsyncChatResource:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncChatResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

    @cached_property
    def run(self) -> RunResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return RunResourceWithRawResponse(self._v2.run)

    @cached_property
    def execute(self) -> ExecuteResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ExecuteResourceWithRawResponse(self._v2.execute)

    @cached_property
    def chat(self) -> ChatResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ChatResourceWithRawResponse(self._v2.chat)


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

    @cached_property
    def run(self) -> AsyncRunResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncRunResourceWithRawResponse(self._v2.run)

    @cached_property
    def execute(self) -> AsyncExecuteResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncExecuteResourceWithRawResponse(self._v2.execute)

    @cached_property
    def chat(self) -> AsyncChatResourceWithRawResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncChatResourceWithRawResponse(self._v2.chat)


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

    @cached_property
    def run(self) -> RunResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return RunResourceWithStreamingResponse(self._v2.run)

    @cached_property
    def execute(self) -> ExecuteResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ExecuteResourceWithStreamingResponse(self._v2.execute)

    @cached_property
    def chat(self) -> ChatResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return ChatResourceWithStreamingResponse(self._v2.chat)


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

    @cached_property
    def run(self) -> AsyncRunResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncRunResourceWithStreamingResponse(self._v2.run)

    @cached_property
    def execute(self) -> AsyncExecuteResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncExecuteResourceWithStreamingResponse(self._v2.execute)

    @cached_property
    def chat(self) -> AsyncChatResourceWithStreamingResponse:
        """
        Create, manage, and execute AI agents with tool access, sandbox environments, and async run workflows
        """
        return AsyncChatResourceWithStreamingResponse(self._v2.chat)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, TypedDict

__all__ = ["V1ProcessParams", "Features", "FeaturesTables"]


class V1ProcessParams(TypedDict, total=False):
    document_url: Required[str]
    """URL or S3 path to the document to process"""

    callback_url: str
    """URL to receive completion webhook"""

    document_id: str
    """Optional custom document identifier"""

    engine: Literal["doctr", "paddleocr"]
    """OCR engine to use"""

    features: Features
    """Additional processing options"""

    result_bucket: str
    """S3 bucket to store results"""

    result_prefix: str
    """S3 key prefix for results"""


class FeaturesTables(TypedDict, total=False, extra_items=object):  # type: ignore[call-arg]
    """Extract tables as structured data"""

    format: Literal["csv", "json"]
    """Output format for extracted tables"""


class Features(TypedDict, total=False):
    """Additional processing options"""

    embed: Dict[str, object]
    """Generate searchable PDF with text layer"""

    forms: Dict[str, object]
    """Detect and extract form fields"""

    tables: FeaturesTables
    """Extract tables as structured data"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["TranscriptionCreateResponse"]


class TranscriptionCreateResponse(BaseModel):
    id: Optional[str] = None
    """Unique transcription job ID"""

    source_object_id: Optional[str] = None
    """Source audio object ID (only for vault-based transcription)"""

    status: Optional[Literal["queued", "processing", "completed", "error"]] = None
    """Current status of the transcription job"""

    vault_id: Optional[str] = None
    """Vault ID (only for vault-based transcription)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ProjectCreateParams", "EnvironmentVariable"]


class ProjectCreateParams(TypedDict, total=False):
    git_repo: Required[Annotated[str, PropertyInfo(alias="gitRepo")]]
    """GitHub repository URL or owner/repo identifier"""

    name: Required[str]
    """Human-readable project name"""

    build_command: Annotated[str, PropertyInfo(alias="buildCommand")]
    """Custom build command to override the framework default"""

    environment_variables: Annotated[Iterable[EnvironmentVariable], PropertyInfo(alias="environmentVariables")]
    """Environment variables to create before the first deployment"""

    framework: str
    """Framework preset for the hosting project, such as nextjs or remix"""

    git_branch: Annotated[str, PropertyInfo(alias="gitBranch")]
    """Git branch to deploy. Defaults to main."""

    install_command: Annotated[str, PropertyInfo(alias="installCommand")]
    """Custom install command to override the framework default"""

    output_directory: Annotated[str, PropertyInfo(alias="outputDirectory")]
    """Build output directory relative to the project root"""

    root_directory: Annotated[str, PropertyInfo(alias="rootDirectory")]
    """Repository subdirectory that contains the app to deploy"""


class EnvironmentVariable(TypedDict, total=False):
    key: Required[str]
    """Environment variable name"""

    target: Required[List[Literal["production", "preview", "development"]]]
    """Deployment targets that should receive this variable"""

    value: Required[str]
    """Environment variable value"""

    type: Literal["plain", "encrypted", "secret"]
    """Storage mode for the environment variable value"""
